@@ -3,8 +3,10 @@ import os
 
 this_dir, this_filename = os.path.split(__file__)
 DATA_PATH = os.path.join(this_dir, "example_data", "example_irr.csv")
-example_irr = pd.read_csv(DATA_PATH, header=6, skipfooter=12, engine='python', index_col='time')
+example_irr = pd.read_csv(DATA_PATH, index_col='time')
 
 this_dir, this_filename = os.path.split(__file__)
 DATA_PATH = os.path.join(this_dir, "example_data", "example_load.csv")
-example_load = pd.read_csv(DATA_PATH, sep=',')
+example_load = pd.read_csv(DATA_PATH, index_col='time')
+
+
